@@ -1,6 +1,9 @@
+import os
+import shutil
 import unittest
 
 from osc.gitea_api import dt_sanitize
+from osc.gitea_api.common import TemporaryDirectory
 
 
 class TestGiteaApiCommon(unittest.TestCase):
@@ -21,5 +24,17 @@ class TestGiteaApiCommon(unittest.TestCase):
         self.assertEqual(expected, actual)
 
 
+    def test_TemporaryDirectory_delete(self):
+        with TemporaryDirectory(delete=True) as temp_dir:
+            pass
+        self.assertFalse(os.path.isdir(temp_dir))
+
+    def test_TemporaryDirectory_no_delete(self):
+        with TemporaryDirectory(delete=False) as temp_dir:
+            pass
+        self.assertTrue(os.path.isdir(temp_dir))
+        shutil.rmtree(temp_dir)
+
+
 if __name__ == "__main__":
     unittest.main()
